# ML Data Provider

This agent sells ML data for training.

## Description

This agent is part of the Fetch.ai ML skill demo. It uses its primary skill, the `fetchai/ml_data_provider` skill, to register its 'ML-data-selling' service on the `SOEF`. 

It can be contacted by another agent (for example the `fetchai/ml_train` agent) to provide specific data samples. 

Once such a request is made and the terms of trade are agreed by both agents, it delivers the data after receiving payment.

## Links

* <a href="https://docs.fetch.ai/aea/ml-skills/" target="_blank">ML Demo</a>
